import setuptools

setuptools.setup(
	name='Pymenulist',
	version='1.1.1',
	author='Rushpy',
	author_email='oivan4218@gmail.com',
	description='Create console menu',
	packages=['Pymenulist'],
	classifiers=[
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
	],
	python_requires='>=3.6',
)